use crate::*;

pub const TEXT_COLOR: Color = Color {
    r: 0.839,
    g: 0.839,
    b: 0.839,
    a: 1.0,
};
pub const RED_HIGHLIGHT: Color = Color {
    r: 1.0,
    g: 0.0,
    b: 0.384,
    a: 1.0,
};
pub const RED_HIGHLIGHT_DARK: Color = Color {
    r: 0.369,
    g: 0.145,
    b: 0.227,
    a: 1.0,
};
pub const RED_HIGHLIGHT_BACKGROUND: Color = Color {
    r: 0.110,
    g: 0.0,
    b: 0.043,
    a: 1.0,
};
pub const AZURE_HIGHLIGHT: Color = Color {
    r: 0.0,
    g: 0.831,
    b: 1.0,
    a: 1.0,
};
pub const AZURE_HIGHLIGHT_DARK: Color = Color {
    r: 0.051,
    g: 0.439,
    b: 0.510,
    a: 1.0,
};
pub const AZURE_HIGHLIGHT_BACKGROUND: Color = Color {
    r: 0.0,
    g: 0.059,
    b: 0.078,
    a: 1.0,
};
pub const GREEN_HIGHLIGHT: Color = Color {
    r: 0.231,
    g: 0.769,
    b: 0.333,
    a: 1.0,
};

pub const BUTTON_BACKGROUND_COLOR: Color = Color {
    r: 0.1,
    g: 0.1,
    b: 0.1,
    a: 1.0,
};

pub const CLEAR_COLOR: Color = Color {
    r: 0.0,
    g: 0.0,
    b: 0.0,
    a: 0.0,
};

pub const BLACK: Color = Color {
    r: 0.0,
    g: 0.0,
    b: 0.0,
    a: 1.0,
};

pub const CONTROL_BACKGROUND: Color = Color {
    r: 0.138,
    g: 0.138,
    b: 0.148,
    a: 1.0,
};
pub const MEDIUM_GRAY: Color = Color {
    r: 0.533,
    g: 0.533,
    b: 0.533,
    a: 1.0,
};